<template>
  <PreviewImage :mode="openScale ? 'scaleToFill' : 'widthFix'" :style="_style" v-bind="omitProps" />
</template>

<script setup lang="ts">
import PreviewImage from './PreviewImage.vue';
import { previewImageProps } from './previewImage';
import Taro from '@tarojs/taro';
import { CSSProperties, computed, reactive, watch } from 'vue';
import _ from 'lodash';

defineOptions({
  name: 'AutoWidthImage',
});

const props = defineProps({
  ...previewImageProps,
  openScale: {
    type: Boolean,
  },
});

const omitProps = computed(() => _.omit(props, ['openScale']));

const MaxHeight = 200;
const MaxWidth = 200;

const state = reactive({
  width: 0,
  height: 0,
});

watch(
  () => props.src,
  () => {
    if (props.src) {
      Taro.getImageInfo({
        src: props.src,
        success(result) {
          state.width = result.width;
          state.height = result.height;
        },
      });
    }
  },
  {
    immediate: true,
  }
);

const _style = computed(() => {
  if (state.width > state.height) {
    if (props.openScale) {
      const width = Math.min(MaxWidth, state.width);
      const scale = width / state.width;

      return {
        height: `${state.height * scale}px`,
        width: `${width}px`,
      } as CSSProperties;
    } else {
      return {
        width: `${state.width}px`,
        maxWidth: '100%',
      };
    }
  } else {
    const height = Math.min(MaxHeight, state.height);
    const scale = height / state.height;
    return {
      height: `${height}px`,
      width: `${state.width * scale}px`,
    } as CSSProperties;
  }
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.auto-width-image-wrapper {
  width: auto !important;
  height: auto !important;
}
</style>
